@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -91,8 +91,10 @@ import com.openexchange.admin.rmi.exceptions.OXContextException;
 import com.openexchange.admin.rmi.exceptions.StorageException;
 import com.openexchange.admin.rmi.extensions.OXCommonExtension;
 import com.openexchange.admin.storage.interfaces.OXContextStorageInterface;
+import com.openexchange.admin.storage.interfaces.OXToolStorageInterface;
 import com.openexchange.admin.storage.interfaces.OXUserStorageInterface;
 import com.openexchange.admin.storage.interfaces.OXUtilStorageInterface;
+import com.openexchange.admin.storage.mysqlStorage.OXToolMySQLStorage;
 import com.openexchange.admin.taskmanagement.TaskManager;
 import com.openexchange.admin.tools.DatabaseDataMover;
 import com.openexchange.admin.tools.FilestoreDataMover;
@@ -1073,18 +1075,23 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
     }
 
     private void addExtensionToContext(List<Context> ctxs, List<OXCommonExtension> retval, String bundlename) throws PluginException {
-        if (null == retval) {
-            throw new PluginException("The plugin: " + bundlename + " returned an empty extension list, this is not allowed");
-        }
-        if (retval.size() != ctxs.size()) {
-            throw new PluginException("After the call of plugin: " + bundlename + " the size of the context and the extensions differ");
-        }
-        for (int i = 0; i < retval.size(); i++) {
-            try {
-                ctxs.get(i).addExtension(retval.get(i));
-            } catch (final DuplicateExtensionException e) {
-                throw new PluginException(e);
+        if (null != retval) {
+            if (retval.size() != ctxs.size()) {
+                throw new PluginException("After the call of plugin: " + bundlename + " the size of the context and the extensions differ");
+            }
+            for (int i = 0; i < retval.size(); i++) {
+                try {
+                    ctxs.get(i).addExtension(retval.get(i));
+                } catch (final DuplicateExtensionException e) {
+                    throw new PluginException(e);
+                }
             }
         }
     }
+    
+    public int getAdminId(Context ctx, Credentials auth) throws RemoteException, InvalidCredentialsException, StorageException {
+        new BasicAuthenticator(context).doAuthentication(auth);
+        final OXToolStorageInterface oxtool = OXToolMySQLStorage.getInstance();
+        return oxtool.getAdminForContext(ctx);
+    }
 }
