@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -89,6 +89,16 @@ public class ContextTest extends AbstractTest {
     public static junit.framework.Test suite() {
         return new JUnit4TestAdapter(ContextTest.class);
     }
+    @Test
+    public void testGetAdminId() throws Exception {
+        final Credentials cred = DummyMasterCredentials();
+        final String hosturl = getRMIHostUrl();
+        Context ctx = addSystemContext(getTestContextObject(cred), getRMIHostUrl(), cred);
+
+        OXContextInterface xctx = (OXContextInterface) Naming.lookup(hosturl + OXContextInterface.RMI_NAME);
+        
+        assertEquals(2, xctx.getAdminId(ctx, cred));
+    }
     
     @Test
     public void testGetAndChangeContext() throws Exception {
